==> vdd-0.1.3.tar.gz: vdd-0.1.3/setup.py <==
"""Setup derived from sample.

References
----------

	<https://packaging.python.org/en/latest/distributing.html>
	<https://github.com/pypa/sampleproject>
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

# Markdown README used for Github.
try:
	import pypandoc
	long_description = pypandoc.convert('README.md', 'rst')
	long_description = long_description.replace("\r", "")

except OSError:
	print("Pandoc not found; long_description conversion failure.")
	# fallback to raw content
	with open('README.md', encoding='utf-8') as f:
		long_description = f.read()

except (RuntimeError, ImportError):
	# We're installing, don't bother.
	long_description=''

setup(
	name='vdd',

	# Versions should comply with PEP440.  For a discussion on single-sourcing
	# the version across setup.py and the project code, see
	# https://packaging.python.org/en/latest/single_source_version.html
	version='0.1.3',

	description='Tools to assist value-driven design & decisions',
	long_description=long_description,

	# The project's main homepage.
	url='https://github.com/corriander/vdd',

	download_url='https://github.com/corriander/vdd/archive/v0.1.3.tar.gz',

	# Author details
	author='Alex Corrie',
	author_email='ajccode@gmail.com',

	# Choose your license
	license='MIT',

	# See https://pypi.python.org/pypi?%3Aaction=list_classifiers
	classifiers=[
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		'Development Status :: 3 - Alpha',

		# Indicate who your project is intended for
		'Intended Audience :: Developers',
		'Intended Audience :: Information Technology',
		'Intended Audience :: Science/Research',
		'Intended Audience :: Manufacturing',
		'Topic :: Scientific/Engineering :: Information Analysis',

		# Pick your license as you wish (should match "license" above)
		'License :: OSI Approved :: MIT License',

		# Specify the Python versions you support here. In particular, ensure
		# that you indicate whether you support Python 2, Python 3 or both.
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
	],

	# What does your project relate to?
	keywords='design engineering',

	# You can just specify the packages manually here if your project is
	# simple. Or you can use find_packages().
	packages=find_packages(exclude=['contrib', 'docs', 'tests']),

	# Alternatively, if you want to distribute just a my_module.py, uncomment
	# this:
	#   py_modules=["my_module"],

	# List run-time dependencies here.  These will be installed by pip when
	# your project is installed. For an analysis of "install_requires" vs pip's
	# requirements files see:
	# https://packaging.python.org/en/latest/requirements.html
	install_requires=['numpy'],

	# List additional groups of dependencies here (e.g. development
	# dependencies). You can install these using the following syntax,
	# for example:
	# $ pip install -e .[dev,test]
	extras_require={
		'test': ['coverage', 'mock', 'ddt'],
	},

)

==> vdd-0.2.0.tar.gz: vdd-0.2.0/setup.py <==
"""Setup derived from sample.

References
----------

	<https://packaging.python.org/en/latest/distributing.html>
	<https://github.com/pypa/sampleproject>
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

# Markdown README used for Github.
try:
	import pypandoc
	long_description = pypandoc.convert('README.md', 'rst')
	long_description = long_description.replace("\r", "")

except OSError:
	print("Pandoc not found; long_description conversion failure.")
	# fallback to raw content
	with open('README.md', encoding='utf-8') as f:
		long_description = f.read()

except (RuntimeError, ImportError):
	# We're installing, don't bother.
	long_description=''

setup(
	name='vdd',

	# Versions should comply with PEP440.  For a discussion on single-sourcing
	# the version across setup.py and the project code, see
	# https://packaging.python.org/en/latest/single_source_version.html
	version='0.2.0',

	description='Tools to assist value-driven design & decisions',
	long_description=long_description,

	# The project's main homepage.
	url='https://github.com/corriander/vdd',

	download_url='https://github.com/corriander/vdd/archive/v0.2.0.tar.gz',

	# Author details
	author='Alex Corrie',
	author_email='ajccode@gmail.com',

	# Choose your license
	license='MIT',

	# See https://pypi.python.org/pypi?%3Aaction=list_classifiers
	classifiers=[
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		'Development Status :: 3 - Alpha',

		# Indicate who your project is intended for
		'Intended Audience :: Developers',
		'Intended Audience :: Information Technology',
		'Intended Audience :: Science/Research',
		'Intended Audience :: Manufacturing',
		'Topic :: Scientific/Engineering :: Information Analysis',

		# Pick your license as you wish (should match "license" above)
		'License :: OSI Approved :: MIT License',

		# Specify the Python versions you support here. In particular, ensure
		# that you indicate whether you support Python 2, Python 3 or both.
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.7'
	],

	# What does your project relate to?
	keywords='design engineering requirements analysis',

	# You can just specify the packages manually here if your project is
	# simple. Or you can use find_packages().
	packages=find_packages(exclude=['contrib', 'docs', 'tests']),

	# Alternatively, if you want to distribute just a my_module.py, uncomment
	# this:
	#   py_modules=["my_module"],

	# List run-time dependencies here.  These will be installed by pip when
	# your project is installed. For an analysis of "install_requires" vs pip's
	# requirements files see:
	# https://packaging.python.org/en/latest/requirements.html
	install_requires=['numpy'],

	# List additional groups of dependencies here (e.g. development
	# dependencies). You can install these using the following syntax,
	# for example:
	# $ pip install -e .[dev,test]
	extras_require={
		'test': ['coverage', 'mock', 'ddt'],
	},

)
